@@ -159,20 +159,11 @@ class LatchPersistence(DataPersistence):
             raise ValueError(f"expected a Latch URL (latch://...): {remote_path}")
 
         attempts = 0
-        while True:
-            try:
-                r = _session.post(
-                    self._latch_endpoint + "/api/object-exists-at-url",
-                    json={"object_url": remote_path, "execution_name": _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")},
-                    timeout=90,
-                )
-                break
-            except requests.exceptions.ConnectionError as e:
-                attempts += 1
-                if attempts >= 3:
-                    raise e
-                time.sleep(0.1 * 2**attempts)
-
+        r = _session.post(
+            self._latch_endpoint + "/api/object-exists-at-url",
+            json={"object_url": remote_path, "execution_name": _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")},
+            timeout=90,
+        )
         if r.status_code != 200:
             raise FlyteUserException("failed to check if object exists at url `{}`".format(remote_path))
 
@@ -311,16 +302,27 @@ class LatchPersistence(DataPersistence):
         internal_execution_id = _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")
 
         if internal_execution_id is not None:
-            r = _session.post(
-                endpoint + "/api/begin-upload",
-                json={
-                    "object_url": to_path,
-                    "nrof_parts": nrof_parts,
-                    "content_type": content_type,
-                    "execution_name": internal_execution_id,
-                },
-                timeout=90,
-            )
+
+            attempts = 0
+            while True:
+                try:
+                    r = _session.post(
+                        endpoint + "/api/begin-upload",
+                        json={
+                            "object_url": to_path,
+                            "nrof_parts": nrof_parts,
+                            "content_type": content_type,
+                            "execution_name": internal_execution_id,
+                        },
+                        timeout=90,
+                    )
+                    break
+                except requests.exceptions.ConnectionError as e:
+                    attempts += 1
+                    if attempts >= 3:
+                        raise e
+                    time.sleep(0.1 * 2**attempts)
+
             if r.status_code != 200:
                 raise FlyteUserException("failed to get presigned upload urls for `{}`".format(to_path))
 
